@@ -3,10 +3,12 @@ use warnings;
 
 package Net::FreshBooks::API;
 BEGIN {
-  $Net::FreshBooks::API::VERSION = '0.20';
+  $Net::FreshBooks::API::VERSION = '0.21';
 }
 use Moose;
 
+with 'Net::FreshBooks::API::Role::Common';
+
 #use namespace::autoclean;
 
 use Carp qw( carp croak );
@@ -14,7 +16,6 @@ use Data::Dump qw( dump );
 
 #use Devel::SimpleTrace;
 use Net::FreshBooks::API::Client;
-use Net::FreshBooks::API::Error;
 use Net::FreshBooks::API::Estimate;
 use Net::FreshBooks::API::Gateway;
 use Net::FreshBooks::API::Invoice;
@@ -32,7 +33,6 @@ has 'api_version'         => ( is => 'rw', default => 2.1 );
 has 'auth_realm'          => ( is => 'rw', default => 'FreshBooks' );
 has 'ua'                  => ( is => 'rw', lazy_build => 1 );
 has 'ua_name'             => ( is => 'rw', lazy_build => 1 );
-has 'verbose'             => ( is => 'rw', default => 0 );
 
 # oauth methods
 has 'access_token'        => ( is => 'rw' );
@@ -40,19 +40,6 @@ has 'access_token_secret' => ( is => 'rw' );
 has 'consumer_key'        => ( is => 'rw' );
 has 'consumer_secret'     => ( is => 'rw' );
 
-sub _log {    ## no critic
-
-    my $self = shift;
-    return if !$self->verbose;
-
-    my ( $level, $message ) = @_;
-    $message .= "\n" if $message !~ m{\n/z}x;
-    carp "$level: $message";
-
-    return;
-
-}
-
 sub ping {
     my $self = shift;
     eval { $self->client->list() };
@@ -112,7 +99,7 @@ sub _create_object {
     my $class = 'Net::FreshBooks::API::' . shift;
 
     my $args = shift || {};
-    my $obj = $class->new( { _fb => $self, %$args } );
+    my $obj = $class->new( _fb => $self, %$args );
 
     return $obj;
 
@@ -137,13 +124,14 @@ sub _build_ua {
         keep_alive        => 10,
     );
 
+    # authenticate with and without realms
     $ua->credentials(    #
         $self->service_url->host_port,    # net loc
         $self->auth_realm,                # realm
         $self->auth_token,                # username
         ''                                # password (none - all in username)
     );
-
+    
     $ua->credentials(                     #
         $self->service_url->host_port,    # net loc
         '',                               # realm (none)
@@ -154,6 +142,7 @@ sub _build_ua {
     return $ua;
 }
 
+
 sub delete_everything_from_this_test_account {
 
     my $self = shift;
@@ -235,7 +224,7 @@ Net::FreshBooks::API - Easy OO access to the FreshBooks.com API
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -390,6 +379,10 @@ Returns a L<Net::FreshBooks::API::Client> object.
 
 Creates and returns a new L<Net::FreshBooks::API::Estimate> object.
 
+=head2 gateway
+
+Creates and returns a new L<Net::FreshBooks::API::Gateway> object.
+
 =head2 invoice
 
 Creates and returns a new L<Net::FreshBooks::API::Invoice> object.
